#
# spec file for package sequoia-sqv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sequoia-sqv
Version:        1.3.0
Release:        1.1
Summary:        A simple signature verification program
License:        GPL-2.0-or-later
URL:            https://sequoia-pgp.org/
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  clang
BuildRequires:  fish
BuildRequires:  rust >= 1.79
BuildRequires:  zsh
BuildRequires:  pkgconfig(nettle)
ExclusiveArch:  %{rust_tier1_arches}

%description
sqv verifies detached OpenPGP signatures. It is a replacement for gpgv.
Unlike gpgv, it can take additional constraints on the signature into account.

%package bash-completion
Summary:        Bash completion for %{name}
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%package fish-completion
Summary:        Fish completion for %{name}
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%install
%{cargo_install}

install -Dm644 %{_builddir}/%{name}-%{version}/target/release/build/%{name}-*/out/shell-completions/sqv.bash %{buildroot}%{_datadir}/bash-completion/completions/sqv
install -Dm644 %{_builddir}/%{name}-%{version}/target/release/build/%{name}-*/out/shell-completions/_sqv %{buildroot}%{_datadir}/zsh/site-functions/_sqv
install -Dm644 %{_builddir}/%{name}-%{version}/target/release/build/%{name}-*/out/shell-completions/sqv.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/sqv.fish
install -Dm644 %{_builddir}/%{name}-%{version}/target/release/build/%{name}-*/out/man-pages/sqv*.1 -t %{buildroot}%{_mandir}/man1/

%check
%{cargo_test}

%files
%license LICENSE.txt
%{_bindir}/sqv
%{_mandir}/man1/sqv*

%files bash-completion
%{_datadir}/bash-completion/completions/sqv

%files zsh-completion
%{_datadir}/zsh/site-functions/_sqv

%files fish-completion
%{_datadir}/fish/vendor_completions.d/sqv.fish

%changelog
* Mon May 19 2025 Jan Kužílek <jan.kuzilek@suse.com>
- Update to version 1.3.0:
  * Release 1.3.0.
  * Add support for verifying inline-signed and CSF messages.
  * Update sequoia-man.
  * Implement sqv --policy-as-of.
  * Port to sequoia-openpgp 2.
  * ci: Only publish to gitlab pages adding to the default branch.
  * Use backticks, not single quotes, in help output.
  * Upgrade sequoia-man.
  * Use sequoia-man to generate the man pages.
  * Improve the help output.
  * Remove the sqv-usage file.
  * Rename the sq_cli module.
  * Fix license.
  * ci: use common-ci component
  * remove local all_commits.sh
  * Update Cargo.lock.
  * Update MSRV to 1.79.
  * Update signing policy.
  * add initial openpgp-policy file
  * Update sequoia-openpgp.
  * Switch to jampot container registry.
  * Add key flags and preferences to UID binding in revoked key tests
* Tue Jul 30 2024 Jan Kužílek <jan.kuzilek@suse.com>
- Initial package, version 1.2.1
